==> re-admin-0.17.1.tgz: package/es/components/UserMenu/index.js <==
import { style as _style5 } from 'antd/lib/dropdown/style';
import _default5 from 'antd/lib/dropdown';
import { style as _style4 } from 'antd/lib/avatar/style';
import _default4 from 'antd/lib/avatar';
import { style as _style3 } from 'antd/lib/icon/style';
import _default3 from 'antd/lib/icon';
import { style as _style2 } from 'antd/lib/menu/style';
import _default2 from 'antd/lib/menu';
import { style as _style } from 'antd/lib/modal/style';
import _default from 'antd/lib/modal';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import styles from './styles';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import routerStore from '../../stores/routerStore';

import localize from '../../hocs/localize';

var confirm = _default.confirm;
var Item = _default2.Item;
var UserMenu = (_dec = localize('UserMenu'), _dec(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(UserMenu, _Component);

	function UserMenu() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, UserMenu);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = UserMenu.__proto__ || Object.getPrototypeOf(UserMenu)).call.apply(_ref, [this].concat(args))), _this), _this._handleClick = function (ev) {
			ev.preventDefault();
			var _this$props$localeSto = _this.props.localeStore.data,
			    confirmSignOut = _this$props$localeSto.confirmSignOut,
			    signOut = _this$props$localeSto.signOut;

			confirm({
				title: confirmSignOut,
				onOk: function onOk() {
					_this.context.authStore.logout();
					routerStore.history.replace('/login');
				},
				okText: signOut
			});
		}, _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(UserMenu, [{
		key: 'render',
		value: function render() {
			var _props = this.props,
			    style = _props.style,
			    localeStore = _props.localeStore;

			return React.createElement(
				_default5,
				{
					overlay: React.createElement(
						_default2,
						null,
						React.createElement(
							Item,
							null,
							React.createElement(
								'a',
								{ rel: 'noopener noreferrer', onClick: this._handleClick, href: '#' },
								React.createElement(_default3, { type: 'logout' }),
								' ',
								localeStore.data.signOut
							)
						)
					),
					trigger: ['click']
				},
				React.createElement(
					'div',
					{ style: styles.container(style) },
					React.createElement(_default4, { icon: 'user', size: 'small' }),
					React.createElement(
						'span',
						{ style: styles.text },
						'Admin'
					),
					React.createElement(_default3, { type: 'down' })
				)
			);
		}
	}]);

	return UserMenu;
}(Component), _class2.propTypes = {
	localeStore: PropTypes.object.isRequired,
	style: PropTypes.object
}, _class2.contextTypes = {
	authStore: PropTypes.object
}, _temp2)) || _class);
export { UserMenu as default };

==> re-admin-0.19.0-0.tgz: package/es/components/UserMenu/index.js <==
import { style as _style5 } from 'antd/lib/dropdown/style';
import _default5 from 'antd/lib/dropdown';
import { style as _style4 } from 'antd/lib/avatar/style';
import _default4 from 'antd/lib/avatar';
import { style as _style3 } from 'antd/lib/icon/style';
import _default3 from 'antd/lib/icon';
import { style as _style2 } from 'antd/lib/menu/style';
import _default2 from 'antd/lib/menu';
import { style as _style } from 'antd/lib/modal/style';
import _default from 'antd/lib/modal';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import styles from './styles';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import routerStore from '../../stores/routerStore';
import authStore from '../../stores/authStore';
import localize from '../../hocs/localize';
var confirm = _default.confirm;
var Item = _default2.Item;
var UserMenu = (_dec = localize('UserMenu'), _dec(_class = observer(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(UserMenu, _Component);

	function UserMenu() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, UserMenu);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = UserMenu.__proto__ || Object.getPrototypeOf(UserMenu)).call.apply(_ref, [this].concat(args))), _this), _this._handleClick = function (ev) {
			ev.preventDefault();
			var _this$props$localeSto = _this.props.localeStore.data,
			    confirmSignOut = _this$props$localeSto.confirmSignOut,
			    signOut = _this$props$localeSto.signOut;

			confirm({
				title: confirmSignOut,
				onOk: function onOk() {
					authStore.logout();
					routerStore.history.replace('/login');
				},
				okText: signOut
			});
		}, _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(UserMenu, [{
		key: 'render',
		value: function render() {
			var _props = this.props,
			    style = _props.style,
			    localeStore = _props.localeStore;
			var username = authStore.username;

			return React.createElement(
				_default5,
				{
					overlay: React.createElement(
						_default2,
						null,
						React.createElement(
							Item,
							null,
							React.createElement(
								'a',
								{ rel: 'noopener noreferrer', onClick: this._handleClick, href: '#' },
								React.createElement(_default3, { type: 'logout' }),
								' ',
								localeStore.data.signOut
							)
						)
					),
					trigger: ['click']
				},
				React.createElement(
					'div',
					{ style: styles.container(style) },
					React.createElement(_default4, { icon: 'user', size: 'small' }),
					React.createElement(
						'span',
						{ style: styles.text },
						username
					),
					React.createElement(_default3, { type: 'down' })
				)
			);
		}
	}]);

	return UserMenu;
}(Component), _class2.propTypes = {
	localeStore: PropTypes.object.isRequired,
	style: PropTypes.object
}, _temp2)) || _class) || _class);
export { UserMenu as default };
